@@ -4,7 +4,7 @@ use strict;
 use vars qw($TYPEMAP_KIND $VERSION $class_part $class_decl $star);
 
 # Dev versions will have a _0xx suffix.
-$VERSION = '0.33_007';
+$VERSION = '0.33_008';
 $VERSION = eval $VERSION;  # To accommodate dev version numbers.
 
 # Parse::RecDescent 1.90 and later have an incompatible change
@@ -13,8 +13,8 @@ $VERSION = eval $VERSION;  # To accommodate dev version numbers.
 # Hence various hash keys may or may not need trailing '(s?)' depending on
 # the version of Parse::RecDescent we are using.
 
-require Parse::RecDescent;
-#use Parse::RecDescent;
+BEGIN{ require Parse::RecDescent; }
+# require Parse::RecDescent;
 
 # --------------------------------------------------
 # Patch to deal with Parse::RecDescent's funky version numbers for development
